
.. image:: https://img.shields.io/pypi/pyversions/taurus.svg
    :target: https://pypi.python.org/pypi/taurus
    :alt: Python Versions
    
.. image:: https://img.shields.io/pypi/l/taurus.svg
    :target: https://pypi.python.org/pypi/taurus
    :alt: License
    
.. image:: https://img.shields.io/pypi/v/taurus.svg
    :target: https://pypi.python.org/pypi/taurus
    :alt: Latest Version

.. image:: https://badge.fury.io/gh/taurus-org%2Ftaurus.svg
    :target: https://github.com/taurus-org/taurus
    :alt: GitHub
    
.. image:: https://travis-ci.org/taurus-org/taurus.svg?branch=develop
    :target: https://travis-ci.org/taurus-org/taurus
    :alt: Travis

.. image:: https://ci.appveyor.com/api/projects/status/rxeo3hsycilnyn9k/branch/develop?svg=true
    :target: https://ci.appveyor.com/project/taurusorg/taurus/branch/develop
    :alt: Appveyor


Taurus
========

Taurus is a control and data acquisition python module

Main web site: http://taurus-scada.org


